/****************************************************************/
/* File:        main.c                                          */
/****************************************************************/
/* Author:     Data Converter Plug-In Development Team          */
/*             <dcp-support@list.ti.com>                        */
/*                                                              */
/* Created:    2006  By Texas Instruments Deutschland GmbH     */
/*                                                              */
/* Version:    2.0  /  June 2006                                */
/****************************************************************/
/* Description: Demo program for the ADS1605 connected to a     */
/*              C6713 DSK                                       */
/*                                                              */
/*              The program samples BUFFER_SIZE values and      */
/*              places the values into the r_buffer1 and        */
/*              r_buffer2 arrays.                               */
/*              The variable Ads1605_1.xferInProgress can be    */
/*              used to track the progress of the transfer (it  */
/*              will be 1 while a transfer is in progress).     */
/*                                                              */
/*              The H/W interface between the ASD1605 and the   */
/*              DSP is defined using the Data Converter Support */
/*              tool in Code Composer Studio, which creates the */
/*              software driver for the low level data transfer */
/*                                                              */
/*              The following settings are made in the DSP/BIOS */
/*              configuration tool:                             */
/*              - Mapping of the interrupt for the EDMA         */
/*                transfer complete interrupt to:               */
/*                    _DCPDISP_dispatchEdmaIsr                  */
/*                                                              */
/*              The data read can be viewed by setting a probe- */
/*              point at the dc_rblock(); line in the main      */
/*              routine and connecting it to a graph window     */
/*              with r_buffer1 as the start address, a length of*/
/*              BUFFERSIZE (for both read and display size) and */
/*              a data size of 16 bit unsigned integer          */
/****************************************************************/
/* Jumper settings for the 5-6K Interface Board (Rev B):        */
/*              W1: open         W4: 2-3                        */
/*              W2: 2-3          W5: 2-3                        */
/*              W3: 2-3          W6: 1-2                        */
/*              W7: 1-2          All others: don't care         */
/*              J13: INTb        J14: don't care                */
/*                                                              */
/* Power connections on the 5-6K Interface Board:               */
/*              J1: +/- 6V       J2: +5V                        */
/*                                                              */
/* Jumper settings for the ADS1605 EVM:                         */
/*              W1: 1-2          W7:  1-2                       */
/*              W2: 1-2          W8:  1-2                       */
/*              W3: 1-2          W9:  1-2                       */
/*              W4: 1-2          W10: 1-2                       */
/*              W5: 1-2          W11: 1-2                       */
/*              W6: Closed                                      */
/*                                                              */
/*              J8: 1-2: Closed                                 */
/*                  3-4: Closed                                 */
/*                                                              */
/* DIP switch settings for the ADS1605 EVM:                     */
/*              SW1-1:  ON (0)                                  */
/*              SW1-2:  ON (0)                                  */
/*              SW1-3:  ON (0)                                  */
/*              SW1-4:  ON (0)                                  */
/*              SW1-5:  ON (0)                                  */
/*              SW1-6:  ON (0)                                  */
/*              SW1-7: OFF (1)                                  */
/*              SW1-8:  ON (0)                                  */
/*                                                              */
/* Power connections on the ADS1605 EVM:                        */
/*              J7: +12V                                        */
/*                                                              */
/* Analog signal connections on the ADS1605 EVM:                */
/*              Apply signal to either J1 pin 4 or to J6        */
/*              Analog signal settings:                         */
/*               - Frequency: 20kHz                             */
/*               - Amplitude: 1V                                */
/*               - Offset:    0V                                */
/*                                                              */
/* All the H/W settings above translate to the following        */
/* settings in the data converter support tool:                 */
/*              DSP Tab:     DSP-Type:           TMS320C6713BGDP*/
/*                           DSP Clock:          225 MHz        */
/*              ADS1605 Tab: RD# Address:        0xA0000000     */
/*                           Interrupt:          Ext Int 5      */
/*                           Interrupt Polarity: Direct         */
/*                           Program EMIF:       Checked        */
/****************************************************************/

/* include files for the data converter plug-in                 */
#include "dc_conf.h"
#include "t1605_fn.h"

/* include files for the chip support library                   */
#include <csl.h>
#include <csl_cache.h>
#include <csl_irq.h>

/* miscellaneous include files                                  */
#include <stdio.h>

/* define the size of the buffer                                */
#define BUFFER_SIZE (1024)

/* create the buffer and align it to a cache friendly boundary  */
#pragma DATA_ALIGN (r_buffer1, CACHE_L2_LINESIZE)
#pragma DATA_ALIGN (r_buffer2, CACHE_L2_LINESIZE)
short r_buffer1[BUFFER_SIZE];
short r_buffer2[BUFFER_SIZE];

volatile int iAdsBusy;

/****************************************************************/
/* callback(): Will be called at the end of the transfer and    */
/*             will reset the semaphore for the transfer        */
/****************************************************************/
void callback(void *pDC)
{
   TADS1605 *pADS = pDC;
   volatile unsigned int uiAddress;
   volatile unsigned int uiLength;
   int iIndex;

   /* get the address of the finished buffer                    */
   if (pADS->xferBuffer[0].uiStatus == 2)
      iIndex = 0;
   else
      iIndex = 1;

   uiAddress = (unsigned int)pADS->xferBuffer[iIndex].sBufPtr;
   uiLength = pADS->xferBuffer[iIndex].uiBufSize;

   iAdsBusy--;
}


/****************************************************************/
/* main(): Configures the interface to the ADS1605              */
/*         Finally, issues a block read command to the converter*/
/*         and waits for the completion                         */
/****************************************************************/
int main(void)
{
    int iStatus;
    int i;

    for(i=0; i < BUFFER_SIZE; i++)
        r_buffer1[i] = 0;
    for(i=0; i < BUFFER_SIZE; i++)
        r_buffer2[i] = 0;

    /* call the configuration of the ADS and the interface      */
    iStatus = dc_configure(&Ads1605_1);

    if (!(iStatus == TIDC_NO_ERR))  /* something went wrong     */
    {
        fprintf(stderr, "\nError: ADS1605 init failed!\n");
        abort();
    }

    IRQ_nmiEnable();          /* enable the non-maskable int    */
    IRQ_globalEnable();       /* enable interrupts globally     */

    iAdsBusy = 0;

    while(1)                     /* loop forever                */
    {
        while(iAdsBusy >= 1);    /* transfer in progress?       */

        /* issue a read block command to the converter          */
        dc_rblock(&Ads1605_1,    /* data converter object       */
                  r_buffer1,     /* address of the target buffer*/
                  BUFFER_SIZE,   /* size of the target buffer   */
                  callback);     /* callback function           */

        iAdsBusy++;
		while (iAdsBusy == 2);    /* wait for a free slot        */

        dc_rblock(&Ads1605_1,    /* data converter object       */
                  r_buffer2,     /* address of the target buffer*/
                  BUFFER_SIZE,   /* size of the target buffer   */
                  callback);     /* callback function           */
        iAdsBusy++;
    }
}
/****************************************************************/
/* End of main.c                                                */
/****************************************************************/
